require 'logging'
require 'mechanize'
require "pagedump/version"
require "pagedump/driver"
require "pagedump/driver_error"

module Pagedump
  class << self
    def logger
      Logging.logger[Pagedump]
    end

    def load_drivers path
      if(File.directory?(path))
        Dir[File.join(path, "**/*.rb")].each do |p|
          load_driver p
        end
      elsif(File.file? path)
        load_driver path
      else
        raise "Not a directory: #{path}"
      end
    end

    def driver_exist? driver
      drivers.any?{|d| d == driver || d.name == driver}
    end

    def load_driver path
      require path
      drivers[-1]
    end

    def register_driver driver_cls
      unless driver_cls.is_a?(Class) && driver_cls.superclass == Pagedump::Driver
        raise("Not a driver class: #{driver_cls}")
      end
      logger.debug "Registering driver #{driver_cls}."
      drivers << driver_cls
      driver_cls
    end

    alias :register :register_driver

    def drivers
      @drivers ||= []
    end

    def driver dr
      drivers.find{|c| c.name == dr.to_s} || raise("No such driver: #{dr}")
    end
    alias :"driver[]" :driver

    private

  end
end
